@@ -13,8 +13,7 @@ import re
 import yaml
 
 from diadmin.vctl_cmds.login import di_login
-from diadmin.vctl_cmds.vrep import import_artifact
-from diadmin.vctl_cmds.solution import export_solution_to_repo
+from diadmin.vctl_cmds.vrep import import_artifact, solution_to_repo
 
 VFLOW_PATHS = {'operators':'/files/vflow/subengines/com/sap/python36/operators/',
                'pipelines':'/files/vflow/graphs/',
@@ -81,7 +80,7 @@ def main() :
             basename = args.artifact
         basename = path.basename(basename)
         source = path.join(VFLOW_PATHS[args.artifact_type],basename)
-        export_solution_to_repo(source,args.solution,args.version,args.description)
+        solution_to_repo(source, args.solution, args.version, args.description)
 
 if __name__ == '__main__':
     main()
\ No newline at end of file
